\name{MMiRKAT}
\alias{MMiRKAT}
\title{ Multivariate Microbiome Regression-based Kernel Association Test}
\description{ 
	This function tests the association between microbiome community composition and multiple outcomes
}
\usage{ MMiRKAT(Y, X = NULL, K) }

\arguments{
  \item{Y}{Outcome matrix, each row is a sample and each column is an outcome variable}
  \item{X}{Covariate matrice, which is adjusted for testing association between outcomes and microbiome composition}
  \item{K}{Microbiome kernel matrix}
}
\details{
The function tests the association between overall microbiome composition and multiple outcomes using the kernel machine
regression framework
}
\value{
A p-value for the testing of association between overall microbiome composition and multiple outcomes after adjusting 
for the effects of covariates  
}
\references{
Zhao et al. (2015). Testing in microbiome profiling studies with MiRKAT, the Microbiome Regression--based Kernel Association Test (MiRKAT). The American Journal of Human Genetics, 96(5): 797-807 \cr
Zhan, X., Tong, X., Zhao, N., Maity, A., Wu, M.C. and Chen, J. (2016). A small--sample multivariate kernel machine test
for microbiome association studies. Technical Report. 
}


\examples{
library(vegan)
library(CompQuadForm)
n=200
p=10
Y=matrix(rnorm(n*p,0,1),n,p)
m=500
OTU=matrix(runif(n*m,0,1),n,m)
D=as.matrix(vegdist(OTU, method="bray"))
K.BC=D2K(D)
MMiRKAT(Y,X=NULL,K.BC) 
}
